# Bibliography

  - [Keenan Crane's discrete differential geometry course](https://brickisland.net/DDGSpring2024/). See
in particular the lecture on [discrete plane curves](
https://brickisland.net/DDGSpring2024/wp-content/uploads/2019/02/DDG_458_SP19_Lecture11_DiscreteCurves.pdf).

  - [*Lectures in Discrete Differential Geometry 1 - Plane Curves*, Etienne Vouga, 2014.](
https://www.cs.utexas.edu/users/evouga/uploads/4/5/6/8/45689883/notes1.pdf)

  - [*Can Mean-Curvature Flow Be Made Non-Singular?* Michael Kazhdan, Jake Solomon, and Mirela Ben-Chen.
2012.](https://arxiv.org/abs/1203.6819)

  - [*Mean Curvature Flow and Applications*. Maria Eduarda Duarte and Leonardo Sacht. 2017.](
http://sibgrapi.sid.inpe.br/col/sid.inpe.br/sibgrapi/2017/09.04.18.39/doc/Mean%20Curvature%20Flow%20and%20Applications.pdf)

  - [*Robust Fairing via Conformal Curvature Flow.* Keenan Crane, Ulrich Pinkall, and Peter Schröder. 2014](
https://www.cs.cmu.edu/~kmcrane/Projects/ConformalWillmoreFlow/paper.pdf)

  - [*Rapid blending of closed curves based on curvature flow.* Masahiro Hirano, Yoshihiro Watanabe, and
Masatoshi Ishikawa. 2017.](https://www.sciencedirect.com/science/article/pii/S016783961730016X)
